********************************
*Codes 
*Stock Repurchasing Bias of Mutual Funds
*********************************
global path "xxx"  //set to the path that stores the data

cd "$path"

set more off, perm

*********
*Table 1 Summary statistics
*********
use "$path\analysis_main_sample",clear

**Panel A: Descriptive statistics
sutex2 repurchase Loser, perc(50) varlab digits(3) 
{
preserve
duplicates drop wficn qt, force
sutex2 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, perc(50) varlab digits(3)
restore
}

**Panel B: Repurchased VS Not repurchase
tabstat Loser mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, by(repurchase) s(mean)

gen one=1
foreach var of varlist Loser mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj {
reghdfe `var' repurchase, a(one) cluster(wficn qt)
}

**Panel C: Previous winners VS previous losers
tabstat repurchase mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, by(Loser) s(mean)

foreach var of varlist repurchase mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj{
reghdfe `var' Loser, a(one) cluster(wficn qt)
}

use  "$path\analysis_Ancerno_sample",clear
sutex2 repurchase Loser, perc(50) varlab digits(3) 
tabstat Loser, by(repurchase) s(mean)
gen one=1
reghdfe Loser repurchase, a(one) cluster(client_mgr qt)

tabstat repurchase, by(Loser) s(mean)
reghdfe repurchase Loser , a(one) cluster(client_mgr qt)

********************************************************************************
*Table 2  Univariate tests of repurchasing bias
********************************************************************************
use  "$path\analysis_main_sample", clear


*Aggregate across all fund quarters
//# of prior winners repurchased
egen nwr=count(permno_ext) if repurchase==1 & Loser==0 
//# of prior losers repurchased
egen nlr=count(permno_ext) if repurchase==1 & Loser==1 
//# of opportunities to repurchase prior winners
egen orw=count(permno_ext) if  Loser==0
//# of opportunities to repurchase prior losers
egen orl=count(permno_ext) if Loser==1 
foreach vari of varlist nwr nlr orw orl{
replace `vari'=`vari'[_n-1] if missing(`vari')
replace `vari'=0 if missing(`vari')

}

gen pwr=nwr/orw
gen plr=nlr/orl
*********
*Table 3 Repurchasing bias in a multivariate regression framework
*********
use "$path\analysis_main_sample",clear
estimate clear

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn)


*******************************
*Table 4 Repurchasing bias - Evidence from ANcerno daily trading data
***********************************
use  "$path\analysis_Ancerno_sample",clear

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster  client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster  client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster  client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster  client_mgr )
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster  client_mgr )

*******************************
*Table 5 Robustness checks on standard errors treatmen/Panel A Main Sample
***********************************
use "$path\analysis_main_sample",clear

///////////////////////Cluster by fund

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn)

///////////////////////Cluster by stock

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster permno_num)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster permno_num)

///////////////////////Cluer by quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster qt)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster qt)

//////////////////////Cluster by fund and stock
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn permno_num)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn permno_num)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn permno_num)


///////////////////////Cluster by fund and quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn qt) 
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn qt)


///////////////////////Cluster by stock and quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster permno_num qt)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster permno_num qt)


///////////////////////Cluster by fund, stock and quarter
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn permno_num qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn permno_num qt)
reghdfe repurchase Loser, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn permno_num qt)

*******************************
*Table 5 Robustness checks on standard errors treatmen/Panel B ANcerno Sample
***********************************
use  "$path\analysis_Ancerno_sample",clear

///////////////////////Cluster by fund

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster  client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster  client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster  client_mgr )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster  client_mgr )
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster  client_mgr )

///////////////////////Cluster by stock

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster ncusip_code )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster  ncusip_code )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster  ncusip_code )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster  ncusip_code )
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster  ncusip_code )
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster  ncusip_code )

///////////////////////Cluster by quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster   qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster   qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster   qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster   qt)
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster   qt)

///////////////////////Cluster by fund and stock

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr) vce(cluster client_mgr ncusip_code)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster  client_mgr ncusip_code)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster client_mgr ncusip_code)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster client_mgr ncusip_code)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster client_mgr ncusip_code)
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster ncusip_code client_mgr)

///////////////////////Cluster by fund and quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster client_mgr qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster client_mgr qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster client_mgr qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster client_mgr qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster client_mgr qt)
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster  client_mgr qt)


///////////////////////Cluster by stock and quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster ncusip_code qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster  ncusip_code qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster  ncusip_code qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster  ncusip_code qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster  ncusip_code qt)
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster  ncusip_code qt)

///////////////////////Cluster by fund, stock and quarter

reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(qt) vce(cluster client_mgr qt ncusip_code)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr qt) vce(cluster  client_mgr qt ncusip_code)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr ncusip_code qt) vce(cluster ncusip_code client_mgr qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt ) vce(cluster ncusip_code client_mgr qt)
reghdfe repurchase Loser pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(client_mgr#qt client_mgr#ncusip_code) vce(cluster ncusip_code client_mgr qt)
reghdfe repurchase Loser, a(ncusip_code#qt client_mgr#qt client_mgr#ncusip_code) vce(cluster ncusip_code client_mgr qt)

*******************************
*Table 6: Repurchasing bias conditional on subsequent price changes
***********************************
use "$path\analysis_main_sample",clear
reghdfe repurchase winnerAVG##up pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn)
reghdfe repurchase winnerAVG##up pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn)
reghdfe repurchase winnerAVG##up pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn)
reghdfe repurchase winnerAVG##up pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn)
reghdfe repurchase winnerAVG##up pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn)
reghdfe repurchase winnerAVG##up, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn)

*******************************
*Table 7: Repurchasing bias conditional on fund flows
***********************************
use "$path\analysis_main_sample",clear

{
preserve
keep wficn qdate
gen mdate_flow=mofd(dofq(qdate))
duplicates drop wficn mdate_flow, force 
merge 1:1 wficn mdate_flow using "$path\Fund_flow2020.dta"
sort wficn mdate_flow
gen qdate1=qdate
replace qdate1=qdate[_n-1] if qdate1==. & _merge==2
bysort wficn qdate1: egen flow_sub=sum(flow_month)
drop if qdate==.
replace flow_sub=. if flow_month==. & flow_sub==0 & _merge==1
drop _merge mdate_flow qdate1
bysort wficn (qdate): gen flow_qdate=flow_sub[_n-1]
save "$path\Fund_flow_qdate.dta", replace
restore
}
merge m:1 wficn qdate using "$path\Fund_flow_qdate.dta", nogen keep(master match)
gen outflow_sell=.
replace outflow_sell=0 if flow_qdate>0 & flow_qdate!=.
replace outflow_sell=1 if flow_qdate<0 

reghdfe repurchase Loser##outflow_sell pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn)
reghdfe repurchase Loser##outflow_sell pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn)
reghdfe repurchase Loser##outflow_sell pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn)
reghdfe repurchase Loser##outflow_sell pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn)
reghdfe repurchase Loser##outflow_sell pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn)
reghdfe repurchase Loser##outflow_sell, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn)

{
preserve
keep wficn qt
gen mdate_flow=mofd(dofq(qt))
duplicates drop wficn mdate_flow, force 
merge 1:1 wficn mdate_flow using "$path\Fund_flow2020.dta"
sort wficn mdate_flow
gen qt1=qt
replace qt1=qt[_n-1] if qt1==. & _merge==2
bysort wficn qt1: egen flow_sub=sum(flow_month)
drop if qt==.
replace flow_sub=. if flow_month==. & flow_sub==0 & _merge==1
drop _merge mdate_flow qt1
bysort wficn (qt): gen flow_qt=flow_sub[_n-1]
save "$path\Fund_flow_qt.dta", replace
restore
}
merge m:1 wficn qt using "$path\Fund_flow_qt.dta", nogen keep(master match)
gen inflow_buy=.
replace inflow_buy=0 if flow_qt<0
replace inflow_buy=1 if flow_qt>0 & flow_qt!=.

reghdfe repurchase Loser##inflow_buy pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn)
reghdfe repurchase Loser##inflow_buy pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn)
reghdfe repurchase Loser##inflow_buy pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn)
reghdfe repurchase Loser##inflow_buy pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn)
reghdfe repurchase Loser##inflow_buy pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn)
reghdfe repurchase Loser##inflow_buy, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn)

*******************************
*Table 8: Fund manager changes between sale and repurchase
***********************************
use "$path\analysis_main_sample",clear

gen qd=qdate-1
merge m:1 wficn qd using "$path/single_mgr_id2020.dta", nogen keep(master match)
rename mgr_id mgr_id_sale

replace qd=qdate+1

merge m:1 wficn qd using "$path/single_mgr_id2020.dta", nogen keep(master match)
rename mgr_id mgr_id_rep

replace qd=qt-1

merge m:1 wficn qd using "$path/single_mgr_id2020.dta", nogen keep(master match)
rename mgr_id mgr_id_rep2

drop if missing(mgr_id_sale) | missing(mgr_id_rep)

gen manager_change=(mgr_id_sale!=mgr_id_rep)
replace manager_change=. if manager_change==0 & mgr_id_sale!=mgr_id_rep2


reghdfe repurchase Loser##manager_change pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(qt) vce(cluster wficn)
reghdfe repurchase Loser##manager_change pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn qt) vce(cluster wficn)
reghdfe repurchase Loser##manager_change pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3 mtna_log age turn_ratio exp_ratio volatility_mret ranking_crsp_obj, a(wficn permno_num qt) vce(cluster wficn)
reghdfe repurchase Loser##manager_change pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt) vce(cluster wficn)
reghdfe repurchase Loser##manager_change pre_return3 pre_return4_6  pre_return7_9 pre_return10_12 pre_return_year2 pre_return_year3, a(wficn#qt wficn#permno_num) vce(cluster wficn)
reghdfe repurchase Loser##manager_change, a(permno_num#qt wficn#qt wficn#permno_num) vce(cluster wficn)

*******************************************************************
*Table 9 Repurchasing bias at the fund manager level
*******************************************************************
use "$path\mgt_level_avg", clear
reghdfe repurchase Loser, a(mgr_id qt) vce(cluster mgr_id)
reghdfe repurchase Loser, a(mgr_id#qt) vce(cluster mgr_id)


use "$path\mgt_level_one_fund",clear
reghdfe repurchase Loser, a(mgr_id qt) vce(cluster mgr_id)
reghdfe repurchase Loser, a(mgr_id#qt) vce(cluster mgr_id)

*******************************************************************
*Table 10 How do winnder and loser stocks perform between sale and repurchase
*******************************************************************
use  "$path\analysis_main_sample", clear
keep if repurchase==1
gen mdate=mofd(dofq(qdate))
gen interval_mdate=mdate_rep-mdate

expand interval_mdate, gen(new)
bysort wficn permno_ext qt mdate: egen mdate_rank=rank(mdate), unique
replace mdate=mdate+mdate_rank
drop mdate_rank

*monthly return
merge m:1 ncusip mdate using "$path/ret_ncusip2020.dta",nogen keep(master match)
merge m:1 wficn mdate using "$path/Fund_ret.dta",nogen keep(master match)
drop if missing(ret)
drop if missing(mret_gross)

*weight:funds dollar holding
gen rep_volume=prc_adj*shares_rep

bys wficn mdate: egen winner_holdings=wtmean(ret) if winnerAVG==1, weight(rep_volume)
bys wficn mdate: egen loser_holdings=wtmean(ret) if winnerAVG==0, weight(rep_volume)


egen group=group(wficn mdate)
xtset, clear
xfill winner_holdings loser_holdings, i(group)
bys wficn mdate: egen x=nvals(winnerAVG)
drop if x==1
keep winner_holdings loser_holdings  wficn mdate mret_gross
duplicates drop 

bys mdate: egen winner_holdings_all=mean(winner_holdings)
bys mdate: egen loser_holdings_all=mean(loser_holdings)
bys mdate: egen fund=mean(mret_gross) 

xtset, clear
xfill winner_holdings_all loser_holdings_all fund, i(mdate)

keep winner_holdings_all loser_holdings_all fund mdate
duplicates drop


//merge with the factors
merge m:1 mdate using "$path/Factors.dta", keep(master match) nogen

gen winner_rf=winner_holdings_all-rf
gen loser_rf=loser_holdings_all-rf
gen fund_rf=fund-rf

reg fund_rf mktrf
predict fund_capm_a, res
replace fund_capm_a=fund_capm_a+_b[_cons]
reg fund_rf mktrf smb hml
predict fund_ff3_a, res
replace fund_ff3_a=fund_ff3_a+_b[_cons]
reg fund_rf mktrf smb hml umd
predict fund_carhart4_a, res
replace fund_carhart4_a=fund_carhart4_a+_b[_cons]


reg winner_rf mktrf
predict winner_capm_a, res
replace winner_capm_a=winner_capm_a+_b[_cons]
reg winner_rf mktrf smb hml
predict winner_ff3_a, res
replace winner_ff3_a=winner_ff3_a+_b[_cons]
reg winner_rf mktrf smb hml umd
predict winner_carhart4_a, res
replace winner_carhart4_a=winner_carhart4_a+_b[_cons]

reg loser_rf mktrf
predict loser_capm_a, res
replace loser_capm_a=loser_capm_a+_b[_cons]
reg loser_rf mktrf smb hml
predict loser_ff3_a, res
replace loser_ff3_a=loser_ff3_a+_b[_cons]
reg loser_rf mktrf smb hml umd
predict loser_carhart4_a, res
replace loser_carhart4_a=loser_carhart4_a+_b[_cons]

drop if missing(loser_holdings_all)|missing(winner_holdings_all)|missing(fund)

//Annualize the returns and alphas
foreach var of varlist winner_* loser_* fund*{
	replace `var'=`var'*12
}

ttest winner_holdings_all==fund
ttest loser_holdings_all==fund
ttest winner_holdings_all==loser_holdings_all

ttest winner_capm_a==fund_capm_a 
ttest loser_capm_a==fund_capm_a 
ttest winner_capm_a==loser_capm_a

ttest winner_ff3_a==fund_ff3_a 
ttest loser_ff3_a==fund_ff3_a 
ttest winner_ff3_a==loser_ff3_a

ttest winner_carhart4_a==fund_carhart4_a 
ttest loser_carhart4_a==fund_carhart4_a 
ttest winner_carhart4_a==loser_carhart4_a


*******************************************************************
*Table 11 Performance of repurchased winner and loser stocks after the repurchase
*******************************************************************
use "$path\purchase_repurchase_positions",clear

expand 3, gen (new)
bys wficn permno_ext qt: egen rank=rank(qt), unique

gen mdate=mdate_rep+rank-1+3
replace mdate=mofd(rdate)+rank if missing(mdate)
drop rank new
*monthly return
merge m:1 ncusip mdate using "$path/ret_ncusip2020.dta",nogen keep(master match)
merge m:1 wficn mdate using "$path/Fund_ret.dta",nogen keep(master match)
drop if missing(ret)
drop if missing(mret_gross)

bys wficn mdate: egen winner_holdings=wtmean(ret) if winnerAVG==1, weight(rep_volume)
bys wficn mdate: egen loser_holdings=wtmean(ret) if winnerAVG==0, weight(rep_volume)
bys wficn mdate: egen pur_holdings=wtmean(ret), weight(pur_volume)

bys wficn mdate: egen x=nvals(winnerAVG)

egen group=group(wficn mdate)
xtset, clear
xfill winner_holdings loser_holdings pur_holdings x, i(group)

duplicates drop wficn mdate, force
keep if x==2
replace mdate_rep=mdate_rep-1+3

gen fund_weight=.
replace fund_weight=1 //mtna_rep
drop if missing(fund_weight)
bys mdate: egen winner_holdings_all=wtmean(winner_holdings), weight(fund_weight)
bys mdate: egen loser_holdings_all=wtmean(loser_holdings), weight(fund_weight)
bys mdate: egen holdings_pur=mean(pur_holdings)
bys mdate: egen fund=mean(mret_gross) 



xtset, clear
xfill winner_holdings_all loser_holdings_all holdings_pur fund, i(mdate)
//*_a
duplicates drop mdate, force

//merge with the factors
merge m:1 mdate using "$path/Factors.dta", keep(master match) nogen

gen winner_rf=winner_holdings_all-rf
gen loser_rf=loser_holdings_all-rf
gen fund_rf=fund-rf
gen pur_rf=holdings_pur-rf


reg winner_rf mktrf
predict winner_capm_a, res
replace winner_capm_a=winner_capm_a+_b[_cons]
reg winner_rf mktrf smb hml
predict winner_ff3_a, res
replace winner_ff3_a=winner_ff3_a+_b[_cons]
reg winner_rf mktrf smb hml umd
predict winner_carhart4_a, res
replace winner_carhart4_a=winner_carhart4_a+_b[_cons]

reg fund_rf mktrf
predict fund_capm_a, res
replace fund_capm_a=fund_capm_a+_b[_cons]
reg fund_rf mktrf smb hml
predict fund_ff3_a, res
replace fund_ff3_a=fund_ff3_a+_b[_cons]
reg fund_rf mktrf smb hml umd
predict fund_carhart4_a, res
replace fund_carhart4_a=fund_carhart4_a+_b[_cons]

reg loser_rf mktrf
predict loser_capm_a, res
replace loser_capm_a=loser_capm_a+_b[_cons]
reg loser_rf mktrf smb hml
predict loser_ff3_a, res
replace loser_ff3_a=loser_ff3_a+_b[_cons]
reg loser_rf mktrf smb hml umd
predict loser_carhart4_a, res
replace loser_carhart4_a=loser_carhart4_a+_b[_cons]

drop if missing(pur_rf)

reg pur_rf mktrf
predict pur_capm_a, res
replace pur_capm_a=pur_capm_a+_b[_cons]
reg pur_rf mktrf smb hml
predict pur_ff3_a, res
replace pur_ff3_a=pur_ff3_a+_b[_cons]
reg pur_rf mktrf smb hml umd
predict pur_carhart4_a, res
replace pur_carhart4_a=pur_carhart4_a+_b[_cons]

//Annualize the returns and alphas
foreach var of varlist winner_* loser_* fund* holdings_pur pur_*{
	replace `var'=`var'*12
}

ttest winner_holdings_all==fund
ttest loser_holdings_all==fund
ttest winner_holdings_all==holdings_pur
ttest loser_holdings_all==holdings_pur
ttest winner_holdings_all==loser_holdings_all
ttest holdings_pur==fund

ttest winner_capm_a==fund_capm_a
ttest loser_capm_a==fund_capm_a
ttest winner_capm_a==pur_capm_a
ttest loser_capm_a==pur_capm_a
ttest winner_capm_a==loser_capm_a
ttest pur_capm_a==fund_capm_a

ttest winner_ff3_a==fund_ff3_a
ttest loser_ff3_a==fund_ff3_a
ttest winner_ff3_a==pur_ff3_a
ttest loser_ff3_a==pur_ff3_a
ttest winner_ff3_a==loser_ff3_a
ttest pur_ff3_a==fund_ff3_a


ttest winner_carhart4_a==fund_carhart4_a
ttest loser_carhart4_a==fund_carhart4_a
ttest winner_carhart4_a==pur_carhart4_a
ttest loser_carhart4_a==pur_carhart4_a
ttest winner_carhart4_a==loser_carhart4_a
ttest pur_carhart4_a==fund_carhart4_a


********************
*Figure 1 average returns of stocks that are (not) repurchased
*********************
use "$path\analysis_main_sample",clear

reg ret_sale_FIFO repurchase, cluster(wficn)
reg ret_sale_AVG repurchase, cluster(wficn)


local y1 : variable label ret_sale_FIFO
local y2 : variable label ret_sale_AVG
stack ret_sale_FIFO repurchase ret_sale_AVG repurchase , into(y repurchase) clear
label def _stack 1 "`y1'" 2 "`y2'"
label val _stack _stack
label define repurchase 0 "Not Repurchased" 1 "Repurchased"
label values repurchase repurchase

graph bar y , over(repurchase) over(_stack) ytitle("Mean of Returns") 

********************************************************************************
*Figure 2: Coefficients for Each Return Interval Relative to a Zero Return in the Previous Sale
********************************************************************************

use "$path\analysis_main_sample",clear
input cut_ret
-0.75
-0.65
-0.55
-0.45
-0.35
-0.25
-0.15
-0.05
0.05
0.15
0.25
0.35
0.45
0.55
0.65
0.75
end
xtile break_ret=ret_sale_AVG, cut(cut_ret)
drop cut_ret
 
sum repurchase if break_ret==9
reghdfe repurchase ib9.break_ret, a(wficn permno_num qt) vce(cluster wficn)

coefplot, yline(0) xline(8.5) vertical coeflabels(1.break_ret = "<=-0.75" 2.break_ret = "-0.75 to -0.65" 3.break_ret = "-0.65 to -0.55" 4.break_ret = "-0.55 to -0.45" 5.break_ret = "-0.45 to -0.35" 6.break_ret = "-0.35 to -0.25" 7.break_ret = "-0.25 to -0.15" 8.break_ret = "-0.15 to -0.05" 9.break_ret = "-0.05 to 0.05" 10.break_ret = "0.05 to 0.15" 11.break_ret = "0.15 to 0.25" 12.break_ret = "0.25 to 0.35" 13.break_ret = "0.35 to 0.45" 14.break_ret = "0.45 to 0.55" 15.break_ret = "0.55 to 0.65" 16.break_ret = "0.65 to 0.75" 17.break_ret = ">0.75") drop(_cons) recast(line) ysc(range(-0.02 0.007) titlegap(0.005)) ytitle("Repurchase probability") xtitle("Return on Previous Sale AVG")


use  "$path\analysis_Ancerno_sample",clear
input cut_ret
-0.75
-0.65
-0.55
-0.45
-0.35
-0.25
-0.15
-0.05
0.05
0.15
0.25
0.35
0.45
0.55
0.65
0.75
end
xtile break_ret=ret_sale_AVG, cut(cut_ret)
drop cut_ret

sum repurchase if break_ret==9
reghdfe repurchase ib9.break_ret, a(client_mgr qt ncusip_code) vce(cluster client_mgr)

coefplot, yline(0) xline(8.5) vertical coeflabels(1.break_ret = "<=-0.75" 2.break_ret = "-0.75 to -0.65" 3.break_ret = "-0.65 to -0.55" 4.break_ret = "-0.55 to -0.45" 5.break_ret = "-0.45 to -0.35" 6.break_ret = "-0.35 to -0.25" 7.break_ret = "-0.25 to -0.15" 8.break_ret = "-0.15 to -0.05" 9.break_ret = "-0.05 to 0.05" 10.break_ret = "0.05 to 0.15" 11.break_ret = "0.15 to 0.25" 12.break_ret = "0.25 to 0.35" 13.break_ret = "0.35 to 0.45" 14.break_ret = "0.45 to 0.55" 15.break_ret = "0.55 to 0.65" 16.break_ret = "0.65 to 0.75" 17.break_ret = ">0.75") drop(_cons) recast(line) ysc(range(-0.02 0.007) titlegap(0.005)) ytitle("Repurchase probability") xtitle("Return on Previous Sale AVG")

